==> bplan-base-globals-1.1.0-0b4347.zip: lang/ro/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'ro',
    'language' => 'Română',
    'locale' => 'ro_RO',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value lei',
    'currency.format.negative' => '-:value lei',
    'currency.iso4217.alpha'   => 'RON',
    'currency.iso4217.numeric' => 946,
    'currency.name'            => 'Leu',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Ban',
    'currency.subunit.symbol'  => 'bani',
    'currency.symbol'          => 'lei',

    'date.format'       => 'd.m.Y',
    'datetime.format'   => 'd.m.Y, H:i',
    'datetime.format+'  => 'd.m.Y, H:i:s',
    'datetime.format-+' => 'd.m.Y, H:i',
    'datetime.format++' => 'd.m.Y, H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => '.',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Activează',
    'action.add'           => 'Adaugă',
    'action.cancel'        => 'Anulează',
    'action.cancel-upload' => 'Anulează încărcarea',
    'action.change'        => 'Modifică',
    'action.close'         => 'Închide',
    'action.confirm'       => 'Confirmă',
    'action.deactivate'    => 'Dezactivează',
    'action.delete'        => 'Șterge',
    'action.edit'          => 'Editează',
    'action.import'        => 'Importă',
    'action.print'         => 'Printează',
    'action.save'          => 'Salvează',
    'action.search'        => 'Căutare',
    'action.sync'          => 'Sincronizează',
    'action.upload'        => 'Încarcă fișier',
    'action.verify'        => 'Verifică',
    'action.view'          => 'Vizualizează',

    'languages' => [
        'bg' => 'Bulgărește',
        'de' => 'Germană',
        'en' => 'Engleză',
        'es' => 'Spanish',
        'fr' => 'Franceză',
        'hu' => 'Maghiară',
        'it' => 'Italiană',
        'lt' => 'Lituaniană',
        'pl' => 'Poloneză',
        'ro' => 'Română',
        'ru' => 'Rusă',
        'tr' => 'Turcă',
        'uk' => 'Ucraineană',
    ],

    'option.yes' => 'Da',
    'option.no'  => 'Nu',

    'required-hint'   => 'Câmpurile marcate (<span class="required-marker">:marker</span>) sunt obligatorii',
    'required-marker' => '*',

    'select-option.please-select' => ' -- Vă rugăm să selectați -- ',

    'status.active'   => 'Activ',
    'status.expired'  => 'Expirat',
    'status.inactive' => 'Dezactivat',
    'status.invalid'  => 'Invalid',
    'status.loading'  => 'Se încarcă...',
    'status.not-set'  => 'Neconfigurat',
    'status.valid'    => 'Valabil',

];

==> bplan-base-globals-1.2.0-009337.zip: lang/ro/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'ro',
    'language' => 'Română',
    'locale' => 'ro_RO',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value lei',
    'currency.format.negative' => '-:value lei',
    'currency.iso4217.alpha'   => 'RON',
    'currency.iso4217.numeric' => 946,
    'currency.name'            => 'Leu',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Ban',
    'currency.subunit.symbol'  => 'bani',
    'currency.symbol'          => 'lei',

    'date.format'       => 'd.m.Y',
    'datetime.format'   => 'd.m.Y, H:i',
    'datetime.format+'  => 'd.m.Y, H:i:s',
    'datetime.format-+' => 'd.m.Y, H:i',
    'datetime.format++' => 'd.m.Y, H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => '.',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Activează',
    'action.add'           => 'Adaugă',
    'action.cancel'        => 'Anulează',
    'action.cancel-upload' => 'Anulează încărcarea',
    'action.change'        => 'Modifică',
    'action.close'         => 'Închide',
    'action.confirm'       => 'Confirmă',
    'action.deactivate'    => 'Dezactivează',
    'action.delete'        => 'Șterge',
    'action.edit'          => 'Editează',
    'action.import'        => 'Importă',
    'action.print'         => 'Printează',
    'action.save'          => 'Salvează',
    'action.search'        => 'Căutare',
    'action.sync'          => 'Sincronizează',
    'action.upload'        => 'Încarcă fișier',
    'action.verify'        => 'Verifică',
    'action.view'          => 'Vizualizează',

    'languages' => [
        'bg' => 'Bulgărește',
        'de' => 'Germană',
        'en' => 'Engleză',
        'es' => 'Spanish',
        'fr' => 'Franceză',
        'hu' => 'Maghiară',
        'it' => 'Italiană',
        'lt' => 'Lituaniană',
        'pl' => 'Poloneză',
        'ro' => 'Română',
        'ru' => 'Rusă',
        'tr' => 'Turcă',
        'uk' => 'Ucraineană',
    ],

    'option.yes' => 'Da',
    'option.no'  => 'Nu',

    'required-hint'   => 'Câmpurile marcate (<span class="required-marker">:marker</span>) sunt obligatorii',
    'required-marker' => '*',

    'select-option.no-options-available' => 'Nu există opțiuni disponibile',
    'select-option.please-select'        => ' -- Vă rugăm să selectați -- ',

    'status.active'   => 'Activ',
    'status.expired'  => 'Expirat',
    'status.inactive' => 'Dezactivat',
    'status.invalid'  => 'Invalid',
    'status.loading'  => 'Se încarcă...',
    'status.not-set'  => 'Neconfigurat',
    'status.valid'    => 'Valabil',

];
